//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Application/Application.cpp
//! @brief     Implements class Application
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Application/Application.h"
#include "GUI/utils/Helpers.h"
#include "GUI/utils/hostosinfo.h"
#include <QFile>
#include <QIcon>

Application::Application(int& argc, char** argv)
    : QApplication(argc, argv), m_currentStyle(ApplicationSettings::Style::native)
{
    setApplicationName("BornAgain");
    setApplicationVersion(GUI::Helpers::getBornAgainVersionString());
    setOrganizationName("Forschungszentrum Jülich, Scientific Computing Group at MLZ Garching");

    if (!GUI::Utils::OS::HostOsInfo::isMacHost())
        QApplication::setWindowIcon(QIcon(":/images/BornAgain.ico"));
}

ApplicationSettings& Application::settings()
{
    return m_settings;
}

void Application::loadStyle(ApplicationSettings::Style style)
{
    QString stylesheet;

    switch (style) {
    case ApplicationSettings::Style::light: {
        QFile base(":/styles/Base.stylesheet");
        base.open(QFile::ReadOnly);
        QFile light(":/styles/Light.stylesheet");
        light.open(QFile::ReadOnly);
        stylesheet = base.readAll() + light.readAll();
        break;
    }
    case ApplicationSettings::Style::dark: {
        QFile base(":/styles/Base.stylesheet");
        base.open(QFile::ReadOnly);
        QFile dark(":/styles/Dark.stylesheet");
        dark.open(QFile::ReadOnly);
        stylesheet = base.readAll() + dark.readAll();
        break;
    }
    default: {
        QFile native(":/styles/Native.stylesheet");
        native.open(QFile::ReadOnly);
        stylesheet = native.readAll();
        break;
    }
    }

    setStyleSheet(stylesheet);
    m_currentStyle = style;
}

ApplicationSettings::Style Application::currentStyle()
{
    return m_currentStyle;
}
