//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Application/ApplicationSettings.cpp
//! @brief     Implements class ProjectManager
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Application/ApplicationSettings.h"
#include <QSettings>

namespace {
const QString S_CREATE_NEW_PROJECT_ON_STARTUP = "CreateNewProjectOnStartup";
const QString S_STYLE = "Style";
} // namespace

bool ApplicationSettings::useNativeFileDialog() const
{
#ifdef _WIN32
    return true;
#else
    return false;
#endif
}

bool ApplicationSettings::createNewProjectOnStartup() const
{
    return QSettings().value(S_CREATE_NEW_PROJECT_ON_STARTUP, true).toBool();
}

void ApplicationSettings::setCreateNewProjectOnStartup(bool b)
{
    QSettings().setValue(S_CREATE_NEW_PROJECT_ON_STARTUP, b);
}

ApplicationSettings::Style ApplicationSettings::styleToUse() const
{
    return static_cast<Style>(QSettings().value(S_STYLE, static_cast<int>(Style::native)).toInt());
}

void ApplicationSettings::setStyleToUse(Style style)
{
    QSettings().setValue(S_STYLE, static_cast<int>(style));
}
