//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/ItemWithMaterial.h
//! @brief     Defines abstract item with a material property
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_ITEMWITHMATERIAL_H
#define BORNAGAIN_GUI_MODELS_ITEMWITHMATERIAL_H

#include "GUI/Models/SessionGraphicsItem.h"

class MaterialItem;

class BA_CORE_API_ ItemWithMaterial : public virtual SessionGraphicsItem {
private:
    static const QString P_MATERIAL;

public:
    static bool isMaterialPropertyName(const QString& name);

    //! Set the material this item shall use. Stores the identifier, not the pointer!
    void setMaterial(const MaterialItem* materialItem);

    //! Set "no material defined"
    void setMaterialUndefined();

    QColor materialColor() const;
    QString materialName() const;
    QString materialIdentifier() const;

protected:
    ItemWithMaterial(const QString& model_type);
};

#endif // BORNAGAIN_GUI_MODELS_ITEMWITHMATERIAL_H
