//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/ItemWithParticles.h
//! @brief     Defines abstract item with a material property
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_ITEMWITHPARTICLES_H
#define BORNAGAIN_GUI_MODELS_ITEMWITHPARTICLES_H

#include "Base/Vector/Vectors3D.h"
#include "GUI/Models/SessionGraphicsItem.h"

class RotationItem;
class TransformationItem;
class VectorItem;
class Transform3D;

class BA_CORE_API_ ItemWithParticles : public virtual SessionGraphicsItem {
private:
    static const QString P_ABUNDANCE;
    static const QString P_POSITION;
    static const QString T_TRANSFORMATION;

public:
    double abundance() const;
    void setAbundance(double abundance);
    SessionItem* abundanceItem() const;

    const R3 position() const;
    void setPosition(const R3& position);
    VectorItem* positionItem() const;

    TransformationItem* createTransformationItem();
    void setTransformation(RotationItem* transformation);
    static bool isTransformationTagName(const QString& name);

    //! Returns identity transformation if no rotation is defined at all
    Transform3D rotation() const;

protected:
    ItemWithParticles(const QString& model_type, const QString& abundance_tooltip,
                      const QString& position_tooltip);

    void setDefaultTagTransformation();

private:
    virtual bool isShellParticle() const;
};

#endif // BORNAGAIN_GUI_MODELS_ITEMWITHMATERIAL_H
