//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/LayerItem.h
//! @brief     Defines class LayerItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_LAYERITEM_H
#define BORNAGAIN_GUI_MODELS_LAYERITEM_H

#include "GUI/Models/ItemWithMaterial.h"

class LayerZeroRoughnessItem;
class LayerBasicRoughnessItem;
class ParticleLayoutItem;

class BA_CORE_API_ LayerItem : public ItemWithMaterial {
private:
    static const QString P_THICKNESS;
    static const QString P_ROUGHNESS;
    static const QString P_NSLICES;
    static const QString T_LAYOUTS;

public:
    static const QString M_TYPE;

    LayerItem();

    QVector<ItemWithMaterial*> itemsWithMaterial();

    double thickness() const;
    void setThickness(double thickness);
    SessionItem* thicknessItem() const;
    static bool isThicknessPropertyName(const QString& name);

    template <typename T> T* setRoughnessType();
    SessionItem* roughness() const;
    SessionItem* roughnessItem() const;

    unsigned int numSlices() const;
    void setNumSlices(unsigned int num_slices);

    QVector<ParticleLayoutItem*> layouts() const;

private:
    void updateAppearance(SessionItem* new_parent);
};

template <typename T> T* LayerItem::setRoughnessType()
{
    static_assert(std::is_base_of<LayerZeroRoughnessItem, T>::value
                      || std::is_base_of<LayerBasicRoughnessItem, T>::value,
                  "Class must be one of the roughness items");

    return setGroupPropertyType<T>(P_ROUGHNESS);
}

#endif // BORNAGAIN_GUI_MODELS_LAYERITEM_H
