//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/ParticleLayoutItem.h
//! @brief     Defines class ParticleLayoutItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_PARTICLELAYOUTITEM_H
#define BORNAGAIN_GUI_MODELS_PARTICLELAYOUTITEM_H

#include "GUI/Models/SessionGraphicsItem.h"
#include "GUI/Models/SessionModel.h"

class InterferenceItem;
class ItemWithParticles;

class BA_CORE_API_ ParticleLayoutItem : public SessionGraphicsItem {
private:
    static const QString P_TOTAL_DENSITY;
    static const QString P_WEIGHT;
    static const QString T_PARTICLES;
    static const QString T_INTERFERENCE;

public:
    static const QString M_TYPE;

    ParticleLayoutItem();

    double totalDensity() const;
    void setTotalDensity(double total_density);

    double weight() const;
    void setWeight(double weight);

    QVector<ItemWithParticles*> particles() const;
    void addParticle(ItemWithParticles* particle);

    InterferenceItem* interference() const;
    template <typename T> T* createInterference();
    void setInterference(InterferenceItem* interference);

private:
    void updateDensityAppearance();
    void updateDensityValue();
};

template <typename T> T* ParticleLayoutItem::createInterference()
{
    static_assert(std::is_base_of<InterferenceItem, T>::value,
                  "Class must be derived from InterferenceFunciontItem");

    return model()->insertItem<T>(this, -1, T_INTERFERENCE);
}

#endif // BORNAGAIN_GUI_MODELS_PARTICLELAYOUTITEM_H
