//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/RotationItems.h
//! @brief     Defines class RotationItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_ROTATIONITEMS_H
#define BORNAGAIN_GUI_MODELS_ROTATIONITEMS_H

#include "GUI/Models/SessionItem.h"

class IRotation;
class Transform3D;

using std::unique_ptr;

class BA_CORE_API_ RotationItem : public SessionItem {
public:
    Transform3D rotation() const;

protected:
    explicit RotationItem(const QString& name);
    virtual unique_ptr<IRotation> createRotation() const = 0;
};

class BA_CORE_API_ XRotationItem : public RotationItem {
private:
    static const QString P_ANGLE;

public:
    static const QString M_TYPE;
    XRotationItem();
    void setAngleValue(double angle);

protected:
    virtual unique_ptr<IRotation> createRotation() const override;
};

class BA_CORE_API_ YRotationItem : public RotationItem {
private:
    static const QString P_ANGLE;

public:
    static const QString M_TYPE;
    YRotationItem();
    void setAngleValue(double angle);

protected:
    virtual unique_ptr<IRotation> createRotation() const override;
};

class BA_CORE_API_ ZRotationItem : public RotationItem {
private:
    static const QString P_ANGLE;

public:
    static const QString M_TYPE;
    ZRotationItem();
    void setAngleValue(double angle);

protected:
    virtual unique_ptr<IRotation> createRotation() const override;
};

class BA_CORE_API_ EulerRotationItem : public RotationItem {
private:
    static const QString P_ALPHA;
    static const QString P_BETA;
    static const QString P_GAMMA;

public:
    static const QString M_TYPE;
    EulerRotationItem();
    void setAlphaValue(double alpha);
    void setBetaValue(double beta);
    void setGammaValue(double gamma);

protected:
    virtual unique_ptr<IRotation> createRotation() const override;
};

#endif // BORNAGAIN_GUI_MODELS_ROTATIONITEMS_H
