//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/SimulationOptionsItem.h
//! @brief     Defines class SimulationOptionsItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_SIMULATIONOPTIONSITEM_H
#define BORNAGAIN_GUI_MODELS_SIMULATIONOPTIONSITEM_H

#include "GUI/Models/SessionItem.h"
#include <QMap>

//! The SimulationOptionsItem class holds simulation status (run policy, number of threads,
//! integration flag). Used in SimulationView to define job settings. When job is started,
//! item is copied to the job as a child.

class BA_CORE_API_ SimulationOptionsItem : public SessionItem {
private:
    static const QString P_RUN_IMMEDIATELY;
    static const QString P_NTHREADS;
    static const QString P_COMPUTATION_METHOD_ANALYTICAL;
    static const QString P_MC_POINTS;
    static const QString P_AVERAGE_MATERIAL;
    static const QString P_INCLUDE_SPECULAR_PEAK;

public:
    static const QString M_TYPE;

    explicit SimulationOptionsItem();

    void setNumberOfThreads(int n);
    int numberOfThreads() const;

    void setRunImmediately(bool runImmediately);
    bool runImmediately() const;
    bool runInBackground() const;

    void setUseMonteCarloIntegration(int numberOfPoints);
    void setUseAnalytical();
    bool useMonteCarloIntegration() const;
    bool useAnalytical() const;

    void setNumberOfMonteCarloPoints(int npoints);
    int numberOfMonteCarloPoints() const;

    void setUseAverageMaterials(bool useAverageMaterials);
    bool useAverageMaterials() const;

    void setIncludeSpecularPeak(bool includeSpecularPeak);
    bool includeSpecularPeak() const;
};

#endif // BORNAGAIN_GUI_MODELS_SIMULATIONOPTIONSITEM_H
