//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/CommonWidgets/GroupBoxCollapser.cpp
//! @brief     Implements class GroupBoxCollapser
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GroupBoxCollapser.h"
#include <QBoxLayout>
#include <QGroupBox>
#include <QToolButton>
#include <QVariant>

void GroupBoxCollapser::installIntoGroupBox(QGroupBox* groupBox, bool expanded)
{
    GroupBoxCollapser* p = new GroupBoxCollapser(groupBox);

    if (!expanded) {
        QSignalBlocker b(p->m_toggleButton);
        p->m_toggleButton->setChecked(false);
        p->m_toggleButton->setArrowType(Qt::ArrowType::RightArrow);
        p->m_contentArea->hide();
    }
}

GroupBoxCollapser::GroupBoxCollapser(QGroupBox* groupBox) : QObject(groupBox)
{
    QVBoxLayout* mainLayout = new QVBoxLayout;
    mainLayout->setSpacing(0);
    mainLayout->setContentsMargins(0, 0, 0, 0);

    m_contentArea = new QWidget(groupBox);
    m_contentArea->setLayout(groupBox->layout());

    mainLayout->addWidget(m_contentArea);
    groupBox->setLayout(mainLayout);

    m_toggleButton = new QToolButton(groupBox);
    m_toggleButton->setObjectName("GroupBoxToggler");
    m_toggleButton->setStyleSheet(
        "QToolButton { border: none; text-align: left; font: bold; padding: 5px}");
    m_toggleButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
    m_toggleButton->setCheckable(true);
    m_toggleButton->setText(groupBox->title());
    m_toggleButton->setArrowType(Qt::ArrowType::DownArrow);
    m_toggleButton->setChecked(true);

    groupBox->layout()->setMenuBar(m_toggleButton);
    groupBox->setTitle("");
    groupBox->setProperty("collapsible", true); // helps to distinguish GroupBoxes in stylesheets

    connect(m_toggleButton, &QAbstractButton::clicked, this, &GroupBoxCollapser::toggle);
}

void GroupBoxCollapser::toggle(bool checked)
{
    m_toggleButton->setArrowType(checked ? Qt::ArrowType::DownArrow : Qt::ArrowType::RightArrow);

    if (m_toggleButton->isChecked())
        m_contentArea->show();
    else
        m_contentArea->hide();
}
