//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/InstrumentSelectorWidget.h
//! @brief     Defines class InstrumentSelectorWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTSELECTORWIDGET_H
#define BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTSELECTORWIDGET_H

#include "GUI/Views/CommonWidgets/ItemSelectorWidget.h"

class InstrumentModel;
class QAction;

//! Instrument selector on the left side of InstrumentView.

class InstrumentSelectorWidget : public ItemSelectorWidget {
    Q_OBJECT

public:
    InstrumentSelectorWidget(InstrumentModel* model, QWidget* parent = nullptr);

    QSize sizeHint() const;
    QSize minimumSizeHint() const;

    QList<QAction*> toolbarActions() const;

private slots:
    void onContextMenuRequest(const QPoint& point);
    void onNewGisas();
    void onNewOffSpecular();
    void onNewSpecular();
    void onNewDepthProbe();
    void onRemove();
    void onCopy();
    void updateActions();

private:
    QString suggestInstrumentName(const QString& currentName);
    QMap<QString, int> mapOfNames();
    template <class Instrument> void newInstrument();

public:
    QAction* m_action_new_gisas;
    QAction* m_action_new_offspecular;
    QAction* m_action_new_specular;
    QAction* m_action_new_depthprobe;
    QAction* m_action_remove;
    QAction* m_action_copy;
    QAction* m_action_separator;
};

#endif // BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTSELECTORWIDGET_H
