//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/OffSpecularInstrumentEditor.cpp
//! @brief     Implements class OffSpecularInstrumentEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Views/InstrumentWidgets/OffSpecularInstrumentEditor.h"
#include "GUI/Models/InstrumentItems.h"
#include "GUI/Views/CommonWidgets/StyleUtils.h"
#include "GUI/Views/InstrumentWidgets/DetectorEditor.h"
#include "GUI/Views/InstrumentWidgets/OffSpecularBeamEditor.h"

#include <QVBoxLayout>

OffSpecularInstrumentEditor::OffSpecularInstrumentEditor(QWidget* parent, Qt::WindowFlags f)
    : QWidget(parent, f)
{
    QVBoxLayout* layout = new QVBoxLayout(this);

    m_beamEditor = new OffSpecularBeamEditor(this);
    layout->addWidget(GUI::Utils::Style::createDetailsWidget(m_beamEditor, "Beam parameters"));

    m_detectorEditor = new DetectorEditor(this);
    layout->addWidget(
        GUI::Utils::Style::createDetailsWidget(m_detectorEditor, "Detector parameters"));
}

void OffSpecularInstrumentEditor::setItem(OffSpecularInstrumentItem* item)
{
    m_beamEditor->setItem(item);
    m_detectorEditor->setItem(item);
}
