//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/PolarizationAnalysisEditor.h
//! @brief     Defines class PolarizationAnalysisEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_POLARIZATIONANALYSISEDITOR_H
#define BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_POLARIZATIONANALYSISEDITOR_H

#include <QWidget>

class AnalyzerPropertiesEditor;
class DetectorItem;
class Instrument2DItem;
class VectorEditor;
class VectorItem;

//! Polarization analysis editor (beam polarization, analyzer properies) for instrument editors.
//! Operates on Instrument2DItem.

class PolarizationAnalysisEditor : public QWidget {
    Q_OBJECT

public:
    PolarizationAnalysisEditor(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
    void setItem(Instrument2DItem* item);

private:
    VectorEditor* m_polarizer_editor;
    VectorEditor* m_analyzer_editor;
    AnalyzerPropertiesEditor* m_properties_editor;
    DetectorItem* m_detector_item;
    VectorItem* m_polarizer_item;
    Instrument2DItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_POLARIZATIONANALYSISEDITOR_H
