//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/SphericalAxisEditor.h
//! @brief     Defines class SphericalAxisEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_SPHERICALAXISEDITOR_H
#define BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_SPHERICALAXISEDITOR_H

#include <QWidget>

class BasicAxisItem;
class QDoubleSpinBox;
class QSpinBox;

/// An editor a spherical axis: the user can enter the number of bins and select the range
/// in degrees

class SphericalAxisEditor : public QWidget {

public:
    SphericalAxisEditor(const QString& title, QWidget* parent = nullptr,
                        Qt::WindowFlags f = Qt::WindowFlags());
    void setItem(BasicAxisItem* item);
    void clearItem();

private slots:
    void onNbinsValueChanged(int value);
    void onMinimumValueChanged(double value);
    void onMaximumValueChanged(double value);

private:
    QSpinBox* m_spinbox_nbins;
    QDoubleSpinBox* m_spinbox_minimum;
    QDoubleSpinBox* m_spinbox_maximum;
    BasicAxisItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_SPHERICALAXISEDITOR_H
