//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/SampleView.h
//! @brief     Defines class SampleView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_SAMPLEVIEW_H
#define BORNAGAIN_GUI_VIEWS_SAMPLEVIEW_H

#include <QMainWindow>

class DocksController;
class SampleToolBar;
class SampleToolBox;
class SampleTreeWidget;
class SamplePropertyWidget;
class ScriptPanel;
class RealSpacePanel;
class ProjectDocument;
class DesignerScene;
class DesignerView;

class SampleView : public QMainWindow {
    Q_OBJECT
public:
    enum ESubWindows { TOOLBOX, SAMPLE_TREE, PROPERTY_EDITOR, INFO, REALSPACEPANEL };

    SampleView(QWidget* parent, ProjectDocument* document);

    void toggleRealSpaceView();
    void fillViewMenu(QMenu* menu);

private:
    void createSubWindows();
    void connectSignals();
    void resetLayout();

    DocksController* m_docks = nullptr;
    SampleToolBar* m_toolBar = nullptr;

    DesignerScene* m_designerScene; //! scene which holds all objects
    DesignerView* m_designerView;   //! graphical representation of scene with object
    SampleToolBox* m_toolBox = nullptr;
    SampleTreeWidget* m_treeWidget = nullptr;
    SamplePropertyWidget* m_propertyWidget = nullptr;
    ScriptPanel* m_scriptPanel = nullptr;
    RealSpacePanel* m_realSpacePanel = nullptr;
    ProjectDocument* m_document;
};

#endif // BORNAGAIN_GUI_VIEWS_SAMPLEVIEW_H
