//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/SampleBuilderEngine/ISampleBuilder.h
//! @brief     Defines and implements interface ISampleBuilder.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef USER_API
#ifndef BORNAGAIN_SAMPLE_SAMPLEBUILDERENGINE_ISAMPLEBUILDER_H
#define BORNAGAIN_SAMPLE_SAMPLEBUILDERENGINE_ISAMPLEBUILDER_H

#include <string>

class MultiLayer;

//! Interface to the class capable to build samples to simulate.

class ISampleBuilder {
public:
    ISampleBuilder() = default;
    virtual ~ISampleBuilder() = default;

    virtual MultiLayer* buildSample() const = 0;

    virtual MultiLayer* createSampleByIndex(size_t) { return buildSample(); }
    virtual size_t size() { return 1; }

    void setSampleName(const std::string& name) { m_sample_name = name; }
    std::string sampleName() const { return m_sample_name; }

private:
    std::string m_sample_name;
};

#endif // BORNAGAIN_SAMPLE_SAMPLEBUILDERENGINE_ISAMPLEBUILDER_H
#endif // USER_API
